# PySDL3

[![Logo](https://github.com/Aermoss/PySDL3/blob/main/res/logo.png?raw=true)](https://github.com/Aermoss/PySDL3)

[![Deploy](https://github.com/Aermoss/PySDL3/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Aermoss/PySDL3/actions/workflows/python-publish.yml)
[![PyPI Python Versions](https://img.shields.io/pypi/pyversions/PySDL3)](https://pypi.org/project/PySDL3)
[![PyPI Version](https://img.shields.io/pypi/v/PySDL3.svg)](https://pypi.org/project/PySDL3)
[![PyPI Downloads](https://img.shields.io/pypi/dm/PySDL3.svg)](https://pypi.org/project/PySDL3)
[![PyPI Status](https://img.shields.io/pypi/status/PySDL3.svg)](https://pypi.org/project/PySDL3)

PySDL3 is a pure Python wrapper around the SDL3, SDL3\_mixer, SDL3\_image, SDL3\_net, SDL3\_ttf, and SDL3\_rtf libraries.

## Getting Started
Just run one of the following commands in a terminal:
```
# To install the latest stable version from PyPI:
pip install --upgrade PySDL3

# To install the latest development version from GitHub:
pip install --upgrade git+https://github.com/Aermoss/PySDL3.git
```

## Requirements
There are no additional requirements since the pre-built binaries are provided within the module.

## Documentation
PySDL3 doesn't provide any documentation at the moment, but since the functions are exactly the same, you can use the official [documentation of SDL3](https://wiki.libsdl.org/SDL3).

## License
PySDL3 is available under the MIT license. See the [LICENSE](https://github.com/Aermoss/PySDL3/blob/main/LICENSE) file for more info.
